@@ -1,3 +1,3 @@
 from .client import Client
 from .http import Http
-from .model import Model
\ No newline at end of file
+from .model import *
